import { ExecuteCommandParams, IConnection } from "vscode-languageserver/lib/main";
import { IConnectionLogger } from "../../types/types";
import DiagnosticManager from "./DiagnosticManager";
import WorkspaceManager from "./WorkspaceManager";
/**
 * Runs command sent by the client.
 */
export default class CommandRunner {
    private connection;
    private diagnosticManager;
    private workspaceManager;
    private logger;
    constructor(connection: IConnection, diagnosticManager: DiagnosticManager, workspaceManager: WorkspaceManager, logger: IConnectionLogger);
    /**
     * Compile the story to which the given URI belong.
     *
     * @param params compile parameters, containing a file URI.
     */
    compileStory(params: ExecuteCommandParams): boolean;
    /**
     * Run the story to which the given URI belong.
     *
     * @param params compile parameters, containing a file URI.
     */
    playStory(params: ExecuteCommandParams): boolean;
    /**
     * If a story is currently playing and prompting for a choice selection,
     * select the choice at the given index.
     *
     * @param params parameters, containing the index of the chocie to select.
     */
    selectOption(params: ExecuteCommandParams): void;
    /**
     * Kill the current Inklecate process, if applicable.
     */
    killInklecate(): void;
    /**
     * Compile the story contained in `workspace`.
     * `documentPath` is required to retrieve the proper settings, which
     * are scoped to the resource.
     *
     * @param documentUri the document URI used to retrieved the settings.
     * @param workspace the ink workspace to compile.
     */
    private executeCompileCommand;
}
