"use strict";
// Copyright (c) Frédéric Maquin <fred@ephread.com>
// Licensed under the MIT License.
// See LICENSE in the project root for license information.
Object.defineProperty(exports, "__esModule", { value: true });
const Fs = require("fs-extra");
const Path = require("path");
const main_1 = require("vscode-languageserver/lib/main");
const types_1 = require("../types/types");
const INK_EXTENSIONS = ["ink", "ink2"];
/**
 * Returns `true` if `filePath` point to a file that is a child of
 * the directory `dirPath` points to.
 *
 * @param filePath path to he file.
 * @param dirPath path to the directory.
 */
function isFilePathChildOfDirPath(filePath, dirPath) {
    const relative = Path.relative(dirPath, filePath);
    return !!relative && !relative.startsWith("..") && !Path.isAbsolute(relative);
}
exports.isFilePathChildOfDirPath = isFilePathChildOfDirPath;
/**
 * Transform an InkErrorType into its equivalent DiagnosticSeverity.
 * @param type the InkErrorType to transform.
 */
function getDiagnosticSeverityFromInkErrorType(type) {
    switch (type) {
        case types_1.InkErrorType.RuntimeError:
        case types_1.InkErrorType.Error:
            return main_1.DiagnosticSeverity.Error;
        case types_1.InkErrorType.RuntimeWarning:
        case types_1.InkErrorType.Warning:
            return main_1.DiagnosticSeverity.Warning;
        case types_1.InkErrorType.Todo:
            return main_1.DiagnosticSeverity.Information;
    }
}
exports.getDiagnosticSeverityFromInkErrorType = getDiagnosticSeverityFromInkErrorType;
function isInkFile(filePath, testIfDirectory, logger) {
    try {
        if (testIfDirectory) {
            if (Fs.lstatSync(filePath).isDirectory()) {
                return false;
            }
        }
        const extension = filePath.split(".").pop() || "";
        if (filePath === extension) {
            return false;
        }
        const isInk = (INK_EXTENSIONS.indexOf(extension) > -1);
        return isInk;
    }
    catch (error) {
        logger.console.warn(`File '${filePath}' doesn't exist and will be ignored. - ${error.message}`);
        return false;
    }
}
exports.isInkFile = isInkFile;
//# sourceMappingURL=utils.js.map