import { IConnection, WorkspaceFolder } from "vscode-languageserver/lib/main";
/** Server configuration. */
export interface InkConfigurationSettings {
    mainStoryPath: string;
    inklecateExecutablePath: string;
    runThroughMono: boolean | string;
}
export declare type PartialInkConfigurationSettings = Partial<InkConfigurationSettings>;
/** Thin wrapper around WorkspaceFolder, containing the temporary compilation directory. */
export interface InkWorkspace {
    folder: WorkspaceFolder;
    temporaryCompilationDirectory?: string;
}
/** Capabilities supported by the client. */
export interface Capabilities {
    configuration: boolean;
    workspaceFolder: boolean;
    diagnostic: boolean;
}
/** Errors types returned by Inklecate. */
export declare enum InkErrorType {
    Error = "ERROR",
    Warning = "WARNING",
    RuntimeError = "RUNTIME ERROR",
    RuntimeWarning = "RUNTIME WARNING",
    Todo = "TODO"
}
/** Errors returned by Inklecate.  */
export interface InkError {
    type: InkErrorType;
    filePath: string;
    lineNumber: number;
    message: string;
}
export declare enum Platform {
    MacOs = 0,
    Windows = 1,
    Other = 2
}
export declare namespace Platform {
    function name(platform: Platform): string;
}
export interface IConnectionLogger {
    console: IConsoleLogger;
    showErrorMessage(message: string, shouldLog: boolean): void;
    showWarningMessage(message: string, shouldLog: boolean): void;
    showInformationMessage(message: string, shouldLog: boolean): void;
    reportServerError(): void;
}
export interface IConsoleLogger {
    error(message: string): void;
    warn(message: string): void;
    info(message: string): void;
    log(message: string): void;
}
export declare class InkConnectionLogger implements IConnectionLogger {
    console: IConsoleLogger;
    private connection;
    private verbose;
    constructor(connection: IConnection, verbose?: boolean);
    showErrorMessage(message: string, shouldLog?: boolean): void;
    showWarningMessage(message: string, shouldLog?: boolean): void;
    showInformationMessage(message: string, shouldLog?: boolean): void;
    /**
     * Show a generic server error in the client.
     */
    reportServerError(): void;
}
export declare class InkConsoleLogger implements IConsoleLogger {
    private connection;
    private verbose;
    constructor(connection: IConnection, verbose?: boolean);
    error(message: string): void;
    warn(message: string): void;
    info(message: string): void;
    log(message: string): void;
}
/** Extends InkErrorType enum with convenience functions. */
export declare namespace InkErrorType {
    /**
     * Parses the given string and returns the corresponding `InkErrorType`.
     * If the value could not be found, returns `undefined`.
     *
     * @param errorType the string to parse.
     */
    function parse(errorType: string): InkErrorType | undefined;
}
export interface DocumentPathAndWorkspace {
    documentPath: string;
    workspace: InkWorkspace;
}
export interface RuntimeChoice {
    index: number;
    text: string;
}
/**
 * Parameters sent with the `inkWorkspace/didCompileStory` notification.
 */
export interface DidCompileStoryParams {
    /** Uri of the current workspace (in which the compilation happened). */
    workspaceUri: string;
    /** Uri of the compiled story, a JSON file. */
    storyUri: string;
}
export interface RuntimeTextParams {
    text: string;
}
export interface RuntimeTagParams {
    tags: string[];
}
export interface RuntimeChoicesParams {
    choice: RuntimeChoice;
}
export interface RuntimeErrorParams {
    error: string;
}
