"use strict";
// Copyright (c) Frédéric Maquin <fred@ephread.com>
// Licensed under the MIT License.
// See LICENSE in the project root for license information.
Object.defineProperty(exports, "__esModule", { value: true });
/** Errors types returned by Inklecate. */
var InkErrorType;
(function (InkErrorType) {
    InkErrorType["Error"] = "ERROR";
    InkErrorType["Warning"] = "WARNING";
    InkErrorType["RuntimeError"] = "RUNTIME ERROR";
    InkErrorType["RuntimeWarning"] = "RUNTIME WARNING";
    InkErrorType["Todo"] = "TODO";
})(InkErrorType = exports.InkErrorType || (exports.InkErrorType = {}));
var Platform;
(function (Platform) {
    Platform[Platform["MacOs"] = 0] = "MacOs";
    Platform[Platform["Windows"] = 1] = "Windows";
    Platform[Platform["Other"] = 2] = "Other";
})(Platform = exports.Platform || (exports.Platform = {}));
(function (Platform) {
    function name(platform) {
        switch (platform) {
            case 0: return 'macOS';
            case 1: return 'Windows';
            default: return 'other';
        }
    }
    Platform.name = name;
})(Platform = exports.Platform || (exports.Platform = {}));
class InkConnectionLogger {
    constructor(connection, verbose = true) {
        this.verbose = false;
        this.connection = connection;
        this.console = new InkConsoleLogger(connection, verbose);
        this.verbose = verbose;
    }
    showErrorMessage(message, shouldLog = true) {
        if (shouldLog) {
            this.connection.console.error(message);
        }
        this.connection.window.showErrorMessage(message);
    }
    showWarningMessage(message, shouldLog = true) {
        if (shouldLog) {
            this.connection.console.warn(message);
        }
        this.connection.window.showWarningMessage(message);
    }
    showInformationMessage(message, shouldLog = true) {
        if (shouldLog && this.verbose) {
            this.connection.console.info(message);
        }
        this.connection.window.showInformationMessage(message);
    }
    /**
     * Show a generic server error in the client.
     */
    reportServerError() {
        this.showErrorMessage("An unrecoverable error occured with Ink Language Server. " +
            "Please see the logs for more information.", false);
    }
}
exports.InkConnectionLogger = InkConnectionLogger;
class InkConsoleLogger {
    constructor(connection, verbose = true) {
        this.verbose = false;
        this.connection = connection;
        this.verbose = verbose;
    }
    error(message) {
        this.connection.console.error(message);
    }
    warn(message) {
        this.connection.console.warn(message);
    }
    info(message) {
        if (!this.verbose) {
            return;
        }
        this.connection.console.info(message);
    }
    log(message) {
        if (!this.verbose) {
            return;
        }
        this.connection.console.log(message);
    }
}
exports.InkConsoleLogger = InkConsoleLogger;
/** Extends InkErrorType enum with convenience functions. */
(function (InkErrorType) {
    /**
     * Parses the given string and returns the corresponding `InkErrorType`.
     * If the value could not be found, returns `undefined`.
     *
     * @param errorType the string to parse.
     */
    function parse(errorType) {
        switch (errorType) {
            case "ERROR":
                return InkErrorType.Error;
            case "WARNING":
                return InkErrorType.Warning;
            case "RUNTIME ERROR":
                return InkErrorType.RuntimeError;
            case "RUNTIME WARNING":
                return InkErrorType.RuntimeWarning;
            case "TODO":
                return InkErrorType.Todo;
            default:
                return undefined;
        }
    }
    InkErrorType.parse = parse;
})(InkErrorType = exports.InkErrorType || (exports.InkErrorType = {}));
//# sourceMappingURL=types.js.map